# -*- coding: utf-8 -*-
"""
Metadata.
"""

__title__ = "SweetRPG API Core"
__description__ = "Common code for API microservice applications"
__url__ = "https://github.com/sweetrpg/api-core"
__version__ = "0.0.211"
__build__ = 0x000003
__author__ = "Paul Schifferer"
__author_email__ = "dm@sweetrpg.com"
__license__ = "MIT"
__copyright__ = "Copyright 2023 SweetRPG"
__cake__ = "\u2728 \U0001f370 \u2728"
